Coverage for C:\src\imod-python\imod\flow\ani.py: 100%

1# -*- coding: utf-8 -*-

2 from imod.flow.pkgbase import Package

3

4

5 class HorizontalAnisotropy(Package):

6 """

7 Horizontal anisotropy is a phenomenon in which the horizontal hydraulic

8 conductivity is not equal along the x and y Cartesian axes. iMODFLOW can

9 calculate this anisotropy based on a anisotropy factor and an anisotropy

10 angle. iMODFLOW also accounts for the cross-terms in the horizontal

11 hydraulic conductivity tensor.

12

13 See also section 12.14 "ANI Horizontal anisotropy module" in the iMOD v5.2

14 manual for further explanation.

15

16 Parameters

17 ----------

18 anisotropy_factor : xr.DataArray

19 The anisotropy factor is defined perpendicular to the main principal

20 axis. The factor is between 0.0 (full anisotropic) and 1.0 (full isotropic)

21 anisotropy_angle : xr.DataArray

22 The anisotropy angle denotes the angle along the main principal axis

23 (highest permeability k) measured in degrees from

24 north (0°), east (90°), south (180°) and west (270°).

25 """

26

27 _pkg_id = "ani"

28 _variable_order = ["anisotropy_factor", "anisotropy_angle"]

29

30 def __init__(self, anisotropy_factor, anisotropy_angle):

31 super().__init__()

32 self.dataset["anisotropy_factor"] = anisotropy_factor

33 self.dataset["anisotropy_angle"] = anisotropy_angle